#
# spec file for package tuned
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_tmpfilesdir:%global _tmpfilesdir /usr/lib/tmpfiles.d}

Name:           tuned
Version:        2.4.1
Release:        5.3
Summary:        A dynamic adaptive system tuning daemon
License:        GPL-2.0+
Group:          System/Base
Url:            https://fedorahosted.org/tuned/
Source:         https://fedorahosted.org/releases/t/u/tuned/tuned-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE fix-allow-receive_sender-default.patch <allow receive_sender="com.redhat.com"/> allow receive_* is normally 
# not needed as that is the default --<p.drouand@gmail.com>
Patch0:         fix-allow-receive_sender-default.patch
# PATCH-FIX-OPENSUSE tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch --use cpupower instead of energy class
Patch2:         tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch
# PATCH-FIX-UPSTREAM tuned-powertop2tuned-fix-KeyError-on-id-attribute.patch --use get function when define id attribute bnc#888599
Patch3:         tuned-powertop2tuned-fix-KeyError-on-id-attribute.patch
BuildRequires:  python
BuildRequires:  systemd
# Do not own standard directories
BuildRequires:  bash-completion
Requires:       /usr/bin/cpupower
Requires:       dbus-1-python
Requires:       ethtool
Requires:       gawk
Requires:       hdparm
Requires:       python-configobj
Requires:       python-decorator
Requires:       python-gobject
Requires:       python-pyudev
Requires:       util-linux
%{?systemd_requires}
BuildArch:      noarch
Obsoletes:      pm-profiler

%description
The tuned package contains a daemon that tunes system settings dynamically.
It does so by monitoring the usage of several system components periodically.
Based on that information components will then be put into lower or higher
power saving modes to adapt to the current usage. Currently only ethernet
network and ATA harddisk devices are implemented.

%package gtk
Summary:        Disk and net statistic monitoring systemtap scripts - GTK GUI
Group:          System/Base
Requires:       %{name} = %{version}
Requires:       polkit
Requires:       powertop

%description gtk
GTK GUI that can control tuned and provide simple profile editor.

%package profiles-sap
Summary:        Additional tuned profile(s) targeted to SAP NetWeaver loads
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-sap
Additional tuned profile(s) targeted to SAP NetWeaver loads.

%package profiles-sap-hana
Summary:        Additional tuned profile(s) targeted to SAP HANA loads
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-sap-hana
Additional tuned profile(s) targeted to SAP HANA loads.

%package profiles-atomic
Summary:        Additional tuned profiles targeted to Atomic
Group:          System/Base
Requires:       %{name} = %{version}

%description profiles-atomic
Additional tuned profiles targeted to Atomic host and guest.

%package utils
Summary:        Disk and net statistic monitoring systemtap scripts
Group:          System/Base
Requires:       %{name} = %{version}
Requires:       powertop

%description utils
This package contains utilities that can help you to fine tune your
system and manage tuned profiles.

%package utils-systemtap
Summary:        Disk and net statistic monitoring systemtap scripts
Group:          System/Base
Requires:       %{name} = %{version}
Requires:       systemtap

%description utils-systemtap
This package contains several systemtap scripts to allow detailed
manual monitoring of the system. Instead of the typical IO/sec it collects
minimal, maximal and average time between operations to be able to
identify applications that behave power inefficient (many small operations
instead of fewer large ones).

%prep
%setup -q
%patch0 -p1
%patch2 -p1
%patch3 -p1

%build
#The tuned daemon is written in pure Python. Nothing requires to be built.
# Just a hack to avoid installation in a wrong directory
sed -i 's|usr/libexec/tuned|%{_libexecdir}/%{name}|' Makefile

%install
make install DESTDIR=%{buildroot}
%py_compile %{buildroot}
rm -rf %{buildroot}/%{_datadir}/doc
# Remove unwanted stuffs instead of exclude them in files list
rm -rf %{buildroot}%{_libexecdir}/%{name}/{default,desktop-powersave,laptop-ac-powersave,server-powersave,laptop-battery-powersave,enterprise-storage,spindown-disk}
rm %{buildroot}%{_mandir}/man7/tuned-profiles-compat.7
ln -sf service $RPM_BUILD_ROOT/usr/sbin/rctuned

%post
%service_add_post %{name}.service
# convert active_profile from full path to name (if needed)
sed -i 's|.*/\([^/]\+\)/[^\.]\+\.conf|\1|' /etc/tuned/active_profile

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING README
%{_datadir}/bash-completion/completions/tuned
%exclude %{python_sitelib}/tuned/gtk
%{python_sitelib}/tuned
%{_sbindir}/tuned
%{_sbindir}/tuned-adm
%{_sbindir}/rctuned
%exclude %{_libexecdir}/tuned/sap-netweaver
%exclude %{_libexecdir}/tuned/sap-hana
%exclude %{_libexecdir}/tuned/sap-hana-vmware
%exclude %{_libexecdir}/tuned/atomic-host
%exclude %{_libexecdir}/tuned/atomic-guest
%{_libexecdir}/tuned
# active_profile might be empty when built via build service, but typically
# not on a real install -> better do not mark it %ghost
%config(noreplace) %verify(not size mtime md5) %{_sysconfdir}/tuned/active_profile
%config(noreplace) %{_sysconfdir}/tuned/tuned-main.conf
%config(noreplace) %verify(not size mtime md5) %{_sysconfdir}/tuned/bootcmdline
%config %{_sysconfdir}/dbus-1/system.d/com.redhat.tuned.conf
%{_sysconfdir}/grub.d
%{_tmpfilesdir}/tuned.conf
%{_unitdir}/tuned.service
%dir %{_localstatedir}/log/tuned
%dir /etc/tuned
%{_mandir}/man5/tuned*
%{_mandir}/man7/tuned-profiles.7*
%{_mandir}/man8/tuned*
%dir %{_datadir}/tuned

%files gtk
%defattr(-,root,root,-)
%{_sbindir}/tuned-gui
%{python_sitelib}/tuned/gtk
%{_datadir}/tuned/ui
%{_datadir}/polkit-1/actions/org.tuned.gui.policy

%files profiles-sap
%defattr(-,root,root,-)
%{_libexecdir}/tuned/sap-netweaver
%{_mandir}/man7/tuned-profiles-sap.7*

%files profiles-sap-hana
%defattr(-,root,root,-)
%{_libexecdir}/tuned/sap-hana
%{_libexecdir}/tuned/sap-hana-vmware
%{_mandir}/man7/tuned-profiles-sap-hana.7*

%files profiles-atomic
%defattr(-,root,root,-)
%{_libexecdir}/tuned/atomic-host
%{_libexecdir}/tuned/atomic-guest
%{_mandir}/man7/tuned-profiles-atomic.7*

%files utils
%defattr(-,root,root,-)
%doc COPYING
%{_bindir}/powertop2tuned

%files utils-systemtap
%defattr(-,root,root,-)
%doc doc/README.utils doc/README.scomes COPYING
%{_sbindir}/varnetload
%{_sbindir}/netdevstat
%{_sbindir}/diskdevstat
%{_sbindir}/scomes
%{_mandir}/man8/varnetload.*
%{_mandir}/man8/netdevstat.*
%{_mandir}/man8/diskdevstat.*
%{_mandir}/man8/scomes.*

%changelog
* Mon Jan  5 2015 p.drouand@gmail.com
- Add tuned-powertop2tuned-fix-KeyError-on-id-attribute.patch;
  fix bnc#888599
* Fri Oct 17 2014 oholecek@suse.com
- Update to version 2.4.1
  + plugin_disk: set_spindown and set_APM made independent (rhbz#976725)
  + plugin_bootloader: added check for grub2 (rhbz#1150047)
  + tuned-adm: fixed traceback on "tuned-adm list" (rhbz#1149162)
  + plugin_bootloader: 00_tuned do not return error if there is no cmdline (rhbz#1151768, bsc#901180)
  + fixed polkit configuration
- Remove tuned-2.4.0-polkit-tuned-gui-path.patch
* Sat Oct 11 2014 p.drouand@gmail.com
- Remove python-gobject dependency in -gtk subpackage; main package
  already requires python-gobject
* Fri Oct 10 2014 p.drouand@gmail.com
- Update to version 2.4.0
  + rebase tuned to latest upstream (rhbz#1093883)
  + fixed traceback if profile cannot be loaded
    related: rhbz#953128
  + powertop2tuned: fixed traceback if rewriting file instead of dir
    resolves: rhbz#963441
  + throughput-performance: altered dirty ratios for better performance
    resolves: rhbz#1043533
  + latency-performance: leaving THP on its default
    resolves: rhbz#1064510
  + used throughput-performance profile on server by default
    resolves: rhbz#1063481
  + network-latency: added new profile
    resolves: rhbz#1052418
  + network-throughput: added new profile
    resolves: rhbz#1052421
  + recommend.conf: fixed config file
    resolves: rhbz#1069123
  + systemd: added cpupower.service conflict
    resolves: rhbz#1073392
  + balanced: used medium_power ALPM policy
  + added support for >, < assignment modifiers in tuned.conf
  + handled root block devices
  + balanced: used conservative CPU governor
    resolves: rhbz#1124125
  + plugins: added selinux plugin
  + plugin_net: added nf_conntrack_hashsize parameter
  + profiles: added atomic-host profile
    resolves: rhbz#1091977
  + profiles: added atomic-guest profile
    resolves: rhbz#1091979
  + moved profile autodetection from post install script to tuned daemon
    resolves: rhbz#1144067
  + profiles: included sap-hana and sap-hana-vmware profiles
  + man: structured profiles manual pages according to sub-packages
  + added missing hdparm dependency
    resolves: rhbz#1144858
  + improved error handling of switch_profile
    resolves: rhbz#1068699
  + tuned-adm: active: detect whether tuned deamon is running
    related: rhbz#1068699
  + removed active_profile from RPM verification
    resolves: rhbz#1104126
  + plugin_disk: readahead value can be now specified in sectors
    resolves: rhbz#1127127
  + plugins: added bootloader plugin
    resolves: rhbz#1044111
  + plugin_disk: added error counter to hdparm calls
  + plugins: added scheduler plugin
    resolves: rhbz#1100826
  + added tuned-gui
- Add tuned-2.4.0-polkit-tuned-gui-path.patch; fix tuned-gui path
  in polkit policy rule
- Remove fix-new-systemd-tmpfiles.d-path.patch; fixed by upstream
- Update use_cpupower_for_intel_perf_bias to upstream changes
  + Added : tuned-2.4.0-use_cpupower_for_intel_perf_bias.patch
  + Deleted : se_cpupower_for_intel_perf_bias
- Add tuned-gtk, profiles-sap, profiles-sap-hana, and profiles-atomic
  subpackages
- Add hdparm and util-linux requirements; new dependencies
- Add bash-completion build requirement to avoid owning standard
  directory
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Mon Mar 31 2014 trenn@suse.de
- Use cpupower {info,set} -b to set Intel perf bias value instead of
  x86_energy_perf_policy we do not ship.
  Add use_cpupower_for_intel_perf_bias
- Add rctuned service link in /usr/sbin
- Mark pm-profiler obsoleted by this package
* Fri Feb 21 2014 p.drouand@gmail.com
- Add fix-allow-receive_sender-default.patch  allow receive_* is
  normally not needed as that is the default
* Sun Feb  2 2014 cfarrell@suse.com
- license update: GPL-2.0+
  No sign of GPL-2.0 (only) licensed components
* Sun Dec 22 2013 p.drouand@gmail.com
- Update to version 2.3.0
  + audio plugin: fixed audio settings in standard profiles
    resolves: rhbz#1019805
  + video plugin: fixed tunings
  + daemon: fixed crash if preset profile is not available
    resolves: rhbz#953128
  + man: various updates and corrections
  + functions: fixed usb and bluetooth handling
  + tuned: switched to lightweighted pygobject3-base
  + daemon: added global config for dynamic_tuning
    resolves: rhbz#1006427
  + utils: added pmqos-static script for debug purposes
    resolves: rhbz#1015676
  + throughput-performance: various fixes
    resolves: rhbz#987570
  + tuned: added global option update_interval
  + plugin_cpu: added support for x86_energy_perf_policy
    resolves: rhbz#1015675
  + dbus: fixed KeyboardInterrupt handling
  + plugin_cpu: added support for intel_pstate
    resolves: rhbz#996722
  + profiles: various fixes
    resolves: rhbz#922068
  + profiles: added desktop profile
    resolves: rhbz#996723
  + tuned-adm: implemented non DBus fallback control
  + profiles: added sap profile
  + tuned: lowered CPU usage due to python bug
    resolves: rhbz#917587
- Add missing requirements; ethtool, gawk, python-pyudev and powertop
- Replace python-gobject2 with python-gobject in requirements;
  python-gobject2 is depreciated
- Remove unwanted stuff instead of exclude it
* Sun Oct 20 2013 hrvoje.senjan@gmail.com
- Adjust Requires again: we are openSUSE, not Fedora, so require
  python-gobject2 instead of non-existant pygobject2
* Tue Oct 15 2013 hrvoje.senjan@gmail.com
- Update to version 2.2.2:
  * cpu plugin: fixed cpupower workaround
  * cpu plugin: fixed crash if cpupower is installed
- Changes since 2.2.1:
  * audio plugin: fixed error handling in _get_timeout
  * removed cpupower dependency, added sysfs fallback
  * powertop2tuned: fixed parser crash on binary garbage
  * cpu plugin: dropped multicore_powersave as kernel upstream
    already did
  * plugins: options manipulated by dynamic tuning are now
    correctly saved and restored
  * powertop2tuned: added alias -e for --enable option
  * powertop2tuned: new option -m, --merge-profile to select
    profile to merge
  * prefer transparent_hugepage over redhat_transparent_hugepage
  * recommend: use recommend.conf not autodetect.conf
  * tuned.service: switched to dbus type service
  * tuned: new option --pid, -P to write PID file
  * tuned, tuned-adm: added new option --version, -v to show version
  * disk plugin: use APM value 254 for cleanup / APM disable
    instead of 255
  * tuned: new option --log, -l to select log file
  * powertop2tuned: avoid circular deps in include
    (one level check only)
  * powertop2tuned: do not crash if powertop is not installed
  * net plugin: added support for wake_on_lan static tuning
  * loader: fixed error handling
- Require dbus-1-python instead of dbus-python, so the package is
  made installable
* Fri Feb  8 2013 p.drouand@gmail.com
- Update to version 2.2.0:
  * remove nobarrier from virtual-guest (data loss prevention)
  * devices enumeration via udev, instead of manual retrieval
  * support for dynamically inserted devices (currently disk plugin)
  * dropped rfkill plugins (bluetooth and wifi), the code didn't work
- Add Requires:python-configobj tag needed for profiles configuration
* Mon Dec 24 2012 p.drouand@gmail.com
- Update to 2.1.1 version:
  * fix: powertop2tuned execution
  * fix: ownership of /etc/tuned
  * daemon: allow running without selected profile
  * daemon: fix profile merging, allow only safe characters in profile names
  * daemon: implement missing methods in DBus interface
  * daemon: implement profile recommendation
  * daemon: improve daemonization, PID file handling
  * daemon: improved device matching in profiles, negation possible
  * daemon: various internal improvements
  * executables: check for EUID instead of UID
  * executables: run python with -Es to increase security
  * plugins: cpu - fix cpupower execution
  * plugins: disk - fix option setting
  * plugins: mounts - new, currently supports only barriers control
  * plugins: sysctl - fix a bug preventing settings application
  * powertop2tuned: speedup, fix crashes with non-C locales
  * powertop2tuned: support for powertop 2.2 output
  * profiles: progress on replacing scripts with plugins
  * tuned-adm: bash completion - suggest profiles from all supported locations
  * tuned-adm: complete switch to D-bus
  * tuned-adm: full control to users with physical access
- Add a %%post script to try to autodetect the best profile
- Update the patches
- Change subpackages to be more coherent and for don't oblige to install
  useless packages by user
* Tue Oct 30 2012 p.drouand@gmail.com
- Remove rpmlintrc for being acceptable on Factory
* Tue Oct 30 2012 p.drouand@gmail.com
- Use %%doc for the doc files - that will put them automatically into
  /usr/share/doc/packages/tuned. Do not use /usr/share/doc/tuned-%%version
  at all
* Tue Oct 30 2012 p.drouand@gmail.com
- Add %%py_compiles macro for bitcompile .py files
- Add fix-new-systemd-tmpfiles.d-path.patch to fix tmpfiles.d
  directory
* Tue Oct 30 2012 p.drouand@gmail.com
- Update to 2.0.2 version:
  * No changelog available
- Remove compat-profiles: no versions < 2.0 have been provided
* Thu Oct  4 2012 p.drouand@gmail.com
- Some changes to be more "Suse-like":
  * add systemd suse macro
- Add a patch to fix allow receive
* Fri Sep 28 2012 p.drouand@gmail.com
- Initial release of tuned
